//------------------------------------------------------------------- NetIncomeAccountingFSTaxes
// This code produces Figure 2 (Article), that is, 
// it draws the net income available under Status Quo and JF policies to a woman with 2 children
// at all levels of earnings, accounting for Food Stamps and Taxes.
//
// This code has four parts:
// 	PART 1: sets parameters / family
//  PART 2: compute payroll and medicaid taxes
// 	PART 3: compute federal income taxes
// 	PART 4: ccompute EITC
//	PART 5: compute FS grant when FS take up by itself
//  PART 6: compute AFDC welfare grant when welfare taken up by itself
//	PART 7: compute AFDC welfare grant + FS grant when welfare and FS taken up together
//  PART 8: compute JF welfare grant when welfare taken up by itself
//	PART 9: compute JF welfare grant + FS grant when welfare and FS taken up together
//  PART 10: graph net income versus earnings for chosen family
//
// This code take no explicit inputs but does use policy rules and parameters for 1997.
// 
// This code outputs:
// 	1. .pdf files with the CDFs 
// 
// Last Revision: 08/30/2015
//-------------------------------------------------------------------------------------------------------------------------------






//------------------------------------------------ PART 1  ------------------------------------------------------
// Setting a few local variables.
// Choose "representative" family and time period (this code accommodates only family considered in Article).
// Set up data set.
//---------------------------------------------------------------------------------------------------------------
	clear
	graph drop _all
	local nobs = 2500
	local whatwedo = "Figure2"
	local year = 1997 	// calendar year
	local nk = 2		// number of children




	//------------------------------------------------------------------------------
	// Declare all the parameter values for year 1997
	//------------------------------------------------------------------------------
	if `year'==1997 & `nk'==2 {
		//-------------------------------------------------------
		// FS parameters
		//-------------------------------------------------------
		local F = 1111
		local tao0 = 1.3
		local F2 = round(`tao0'*`F',1)
		local tao1 = 0.3
		local tao2 = 0.2
		local tao3 = 0.5
		local d1 = 134
		local s = 250
		local b1 = 315
		//-------------------------------------------------------
		// FS variables
		//-------------------------------------------------------
		local S = 366 // rent of the AU (assumed the same for all earnings)
		//-------------------------------------------------------
		// EITC paramters in 1997 for a family with two kids
		//-------------------------------------------------------
		local y1 = 9140
		local y2 = 11930
		local y3 = 2250
		local etao1 = 0.4
		local etao2 = 0.2106
		//-------------------------------------------------------
		// AFDC parameters in 1997 for a family with two kids
		//-------------------------------------------------------
		local mbs = 745
		local atao = 0.73 // fill the gap budgeting
		local map = floor(`atao'*`mbs')
		//-------------------------------------------------------
		// Choose whether short-term recipient (set month=1 and er=120) or
		// medium-term recipient (set month=5 and er=120) or long-term (month=13 and er=90):
		//	"short-term"
		//	"medium-term"
		//	"long-term"
		//-------------------------------------------------------
		local which_recipient = "long-term" // set yourself
		if "`which_recipient'" == "long-term" {
			local month = 13
			local er = 90 	// 13th month of employment on assistance or later
		}
		else if "`which_recipient'" == "medium-term" {
			local month = 5
			local er = 120 // 5th month of employment on assistance to 12th month
		}
		else if "`which_recipient'" == "short-term" {
			local month = 1 
			local er = 120  // 1st month of of employment on assistance to 4th or 0 such months
		}
		else {
			di "STOP: you mispecified the type of recipient for whom to draw graphs"
			STOP
		}
		//-------------------------------------------------------
		// AFDC breakeven level
		//-------------------------------------------------------
		if (`er'==90|`er'==120) & (`month'==5|`month'==13) {
			local ebreakeven = `mbs'+`er' // mbs + 90 + (it depends) 30
		}
		else if `er'==120&`month'==1 {
			local ebreakeven = (3/2)*`mbs'+`er' // (3/2)mbs + 90 + 30
		}
		//-------------------------------------------------------
		// Payroll and Medicare taxes
		//-------------------------------------------------------
		local tao_payroll = 0.062
		local tao_medicare = 0.0145	
		//-------------------------------------------------------
		// Federal Income Taxes
		//-------------------------------------------------------
		local fy0 = 0
		local fy1 = 33050
		local fy2 = 83350
		local fy3 = 138200
		local fy4 = 271050
		local fy5 = 1000000000
		local ftao1 = 0.15
		local ftao2 = 0.28
		local ftao3 = 0.31
		local ftao4 = 0.36
		local ftao5 = 0.396
		local fe = 2650 // personal exemption, e
		local fd = 6050 // standard deduction, d
		//-------------------------------------------------------
		// description of assistance unit
		//-------------------------------------------------------
		if `month'==5|`month'==13 {
		local myau "Assistance Unit: in 1997, 2 kids, long-term recipient, with {c $|}`S' in monthly rental expenses."
		}
		if `month'==1 {
		local myau "Assistance Unit: in 1997, 2 kids, short-term recipient, with {c $|}`S' in monthly rental expenses."
		}	
	}
	else {
		di "Code does not deal with other years or AU sizes."
		STOP
	}

	//------------------------------------------------------------------------------
	// Set up data set, earnings of mother (from $0 to $2499 in unit increments).
	//------------------------------------------------------------------------------
	set obs `nobs'
	qui gen e = _n-1	








//------------------------------------------------ PART 2  ------------------------------------------------------
// Earnings of the mother net of payroll taxes and medicare taxes.
// (income taxes are not considered because they should not apply to 
// the relatively low earnings leves of these families)
//---------------------------------------------------------------------------------------------------------------
qui gen e_net = e*(1- `tao_payroll'- `tao_medicare') 
qui gen ey = e*12 // gross of payroll/medicare taxes yearly earnings








//------------------------------------------------ PART 3  ------------------------------------------------------
// Federal income taxes applied to gross (of payroll taxes) yearly earnings
// assuming that other income is zero (e.g. from rent or investment), that D1=0,
// that family applies as HOH, that family uses the standard deduction.
// NOTE: this computation does not include assistance income. the computation
// that accounts for the fact that assistance income is federally taxes is below.
//---------------------------------------------------------------------------------------------------------------
qui gen income_taxable = ey - (1+`nk')*`fe' - `fd'
qui gen fita = 0 										if income_taxable-`fy0'<0
qui replace fita = `ftao1'*(income_taxable-`fy0') 		if income_taxable>`fy0'&income_taxable<=`fy1'
qui replace fita = fita+ `ftao2'*(income_taxable-`fy1') if income_taxable>`fy1'&income_taxable<=`fy2'
qui replace fita = fita+ `ftao3'*(income_taxable-`fy2') if income_taxable>`fy2'&income_taxable<=`fy3'
qui replace fita = fita+ `ftao4'*(income_taxable-`fy3') if income_taxable>`fy3'&income_taxable<=`fy4'
qui replace fita = fita+ `ftao5'*(income_taxable-`fy4') if income_taxable>`fy4'&income_taxable<=`fy5'
qui replace fita = fita/12 // monthly federal income tax

local fyy0 = (1+`nk')*`fe'+`fd' // at earnings below this level taxable income is zero or negative so no Federal Income Taxes
local fyy1 = `fy1'+ `fyy0' 		// at earning below this level, and above `fyy0', the tax rate is ftao1
local fyy0 = round(`fyy0'/12,1)  
local fyy1 = round(`fyy1'/12,1)  
 
// define net earnings if person was to file for Federal Income Taxes (and pay payroll and medicare taxes)     
qui gen e_net0 = e_net - fita
     




	 
	 
//------------------------------------------------ PART 4  ------------------------------------------------------
// EITC applied to gross (of payroll taxes) yearly earnings (monthly earnings times 12)
//---------------------------------------------------------------------------------------------------------------
 qui gen eitc = `etao1'*ey if ey<=`y1'
 qui replace eitc = `etao1'*`y1' if ey>`y1'&ey<=`y2'
 qui replace eitc = `etao1'*`y1'-`etao2'*(ey-`y2') if ey>`y2'& `etao1'*`y1'-`etao2'*(ey-`y2')>=0
 qui replace eitc = 0 if ey>`y2'& `etao1'*`y1'-`etao2'*(ey-`y2')<0
 qui replace eitc = 0 if ey>`y1'*(`etao1'/`etao2')+`y2'
 qui replace eitc = 0 if ey==0
 qui replace eitc = eitc/12 // monthly EITC
 
 local yy1 = round(`y1'/12,1)
 local yy2 = round(`y2'/12,1)
 local yy4 = `y1'*(`etao1'/`etao2') + `y2'  // EITC is exhausted
 local yy4 = round(`yy4'/12,1)
    
// define total net income if person was to file for EITC (and pay payroll and medicare taxes and federal income taxes)     
qui gen income_0 = e_net0 +eitc
label variable income_0 "Total earnings net of payroll/medicare/fi taxes and inclusive of EITC"
     
     
     

     
     
     
	 
	 
	 
//------------------------------------------------ PART 5  ------------------------------------------------------
// FS alone (same under JF and control treatments)
// Implicit assumption is that decuctions d3=d4=d5=0 (see policy rules write up)
//---------------------------------------------------------------------------------------------------------------	
qui gen gafd = 0 // grant from welfare when FS alone, by construction

qui gen yn1 = e+gafd-`d1'-`tao2'*e if e<=`F'
qui replace yn1 = e+gafd-`d1'-`tao2'*`F' if e>`F'
qui replace yn1 = 0 if yn1<0

// Excess shelter deduction
qui gen d6 = `s' if `S'-`tao3'*yn1>`s'
qui replace d6 = `S'-`tao3'*yn1 if `S'-`tao3'*yn1>0&`S'-`tao3'*yn1<=`s'
qui replace d6 = 0 if `S'-`tao3'*yn1<=0

qui gen yn2 = yn1-d6
qui replace yn2 = 0 if yn2<0

qui gen gfs = `b1'-`tao1'*yn2 if `b1'-`tao1'*yn2>=0
qui replace gfs = 0 if `b1'-`tao1'*yn2<0

// gross income test
qui replace gfs = 0 if gfs>0&e>`tao0'*`F'

// net income test
qui replace gfs = 0 if gfs>0&yn2>`F'

// define total net income if person was to file for EITC (and pay payroll and medicare taxes) and be on FS
qui gen income = e_net - fita + gafd + gfs +eitc
qui replace income = . if gfs==0 // for the purpouse of the pictures
rename income income_1
 
 

 
 
 
 
 
 
 
 
//------------------------------------------------ PART 6  ------------------------------------------------------
// AFDC-Welfare alone aka control welfare policy
//---------------------------------------------------------------------------------------------------------------	   
 qui replace gafd = . // empty the variable
 qui gen er = `er'
 qui replace er = (1/3)*(e-`er')+`er' if `month'==1
 qui replace gafd = `atao'*(`mbs'-(e-er)) if e>=er&`mbs'>=e-er
 qui replace gafd = `atao'*`mbs'          	if e<er
 qui replace gafd = 0                 		if e>=er&`mbs'<e-er
 
 // define total net income if person was to file for EITC (and pay payroll and medicare taxes)   and be on AFDC
 qui gen income = e_net -fita + gafd + eitc
 qui replace income = . if gafd==0 // for the purpouse of the pictures
 rename income income_2
 
 
 
 
 
 
 
  
//------------------------------------------------ PART 7  ------------------------------------------------------
// AFDC-welfare with FS (need to recompute FS grant because the AFDC-welfare grant counts as income in the 
// derivation of the FS grant)
//---------------------------------------------------------------------------------------------------------------	
 drop yn1
 drop yn2
 drop d6
 rename gfs gfs_alone
 
qui gen yn1 = e+gafd-`d1'-`tao2'*e if e<=`F'
qui replace yn1 = e+gafd-`d1'-`tao2'*`F' if e>`F'
qui replace yn1 = 0 if yn1<0

qui gen d6 = `s' if `S'-`tao3'*yn1>`s'
qui replace d6 = `S'-`tao3'*yn1 if `S'-`tao3'*yn1>0&`S'-`tao3'*yn1<=`s'
qui replace d6 = 0 if `S'-`tao3'*yn1<=0

qui gen yn2 = yn1-d6
qui replace yn2 = 0 if yn2<0

qui gen gfs = `b1'-`tao1'*yn2 if `b1'-`tao1'*yn2>=0
qui replace gfs = 0 if `b1'-`tao1'*yn2<0

// define total net income if person was to file for EITC (and pay payroll and medicare taxes) and be on both AFDC and FS
qui gen income = e_net - fita + gafd + gfs + eitc
qui replace income = . if gfs==0|gafd==0 // for the purpouse of the pictures
rename income income_3





 
 
 
 
 
 
//------------------------------------------------ PART 8  ------------------------------------------------------
// JF-welfare alone
//---------------------------------------------------------------------------------------------------------------
 qui gen gjf = `atao'*`mbs'         if e<=`F'
 qui replace gjf = 0             	if e>`F'
 
 // define total net income if person was to file for EITC (and pay payroll and medicare taxes) and be on JF-TANF
 qui gen income = e_net - fita + gjf + eitc
 qui replace income = . if gjf==0 // for the purpouse of the pictures
 rename income income_4
 
 
 
 
 
 
 
//------------------------------------------------ PART 9  ------------------------------------------------------
// JF with FS (need to recompute FS grant because it depends on the JF-TANF grant which is considered as income
// and also because under JF the rules for the determination of the FS grant are different when FS is taken up
// in conjunction with AFDC compared to when it is taken up by itself)
//--------------------------------------------------------------------------------------------------------------- 
 drop yn1
 drop yn2
 drop d6
 drop gfs
 
qui gen yn1 = e+gjf-`d1'-e //  this is valid as long as e<=`F' but since we compute gfs only up to e<=`F' we are ok
qui replace yn1 = 0 if yn1<0

qui gen d6 = `s' if `S'-`tao3'*yn1>`s'
qui replace d6 = `S'-`tao3'*yn1 if `S'-`tao3'*yn1>0&`S'-`tao3'*yn1<=`s'
qui replace d6 = 0 if `S'-`tao3'*yn1<=0

qui gen yn2 = yn1-d6
qui replace yn2 = 0 if yn2<0

qui gen gfs = `b1'-`tao1'*yn2 if `b1'-`tao1'*yn2>=0&e<=`F'
qui replace gfs = 0 if `b1'-`tao1'*yn2<0
qui replace gfs = 0 if e>`F' // b/c not together with JF so rules are not those just applied to obtain the FS grant

						
 // define total net income if person was to file for EITC (and pay payroll and medicare taxes) and on both JF-TANF and FS
 qui gen income = e_net-fita+gjf+gfs + eitc
 qui replace income = . if gjf==0|gfs==0 // for the purpouse of the pictures
 rename income income_5
 
 
 
 
 
 
 
//------------------------------------------------ PART 10  ------------------------------------------------------
// Overall graphs:
//	- Control policy: only on AFDC, only on FS, on AFDC+FS, on no assistance
//	- JF policy: only on JF, only on FS, on JF+FS, on no assistance
//--------------------------------------------------------------------------------------------------------------- 

// with notes and titles 
 graph twoway line income_0 e, lcolor(black) ||  ///
              connect income_1 e if (mod(_n,30)==1|_n==1), lcolor(black) lpattern(solid) mcolor(black) msymbol(O) msize(vsmall) ||  ///
              line income_4 e, lcolor(red) lpattern(dash) ||  ///
              connect income_5 e if (mod(_n,100)==1|_n==1), lcolor(red*0.5) lpattern(dash) mcolor(red) msymbol(O) msize(vsmall) || ///
              line income_2 e, lcolor(blue) lpattern("-...") ||  ///
              connect income_3 e if (mod(_n,100)==1|_n==1), lcolor(blue*0.5) lpattern("-...") mcolor(blue) msymbol(O) msize(vsmall) || ///
              line e e, lcolor(black) lpattern(shortdash) ///
     xtitle("Gross Earnings", size(small)) ///
     ytitle("Net Income", size(small)) ///
     ylabel(`b1' `map', nogrid angle(horizonal) labsize(small)) ///
     xlabel(`er' `yy1' `ebreakeven' `yy2' `F' `fyy0' `F2' `yy4', nogrid angle(45) labsize(small)) ///
     xline(`er', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`ebreakeven', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`yy1', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`yy2', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`F', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`fyy0', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`F2', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`yy4', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     title("Net Monthly Income with/without Participation in Welfare and FS Programs", size(medium)) ///
     subtitle("Under JF and Control policies", size(medsmall)) ///
     legend( ///
        lab(1 "Off Welfare and FS") ///
        lab(2 "On FS") ///
        lab(3 "On Welfare (JF)") ///
     	lab(4 "On Welfare + FS (JF)") ///
        lab(5 "On Welfare (AFDC)") ///
        lab(6 "On Welfare + FS (AFDC)") ///
        lab(7 "45 degree line") ///
        size(vsmall) ///
        order(7 1 2 3 4 5 6) ///
        region(lwidth(none) lstyle(none) lcolor(white) lpattern(blank) color(none)) ///
        position(4) ring(0) col(1) bmargin(large) ///
     ) ///
     note("`myau'" "Vertical lines: at the AFDC fixed earning disregard and break-even level ({c $|}`er' and {c $|}`ebreakeven'), at the end of the EITC phase-in and start and" "end of the phase-out regions ({c $|}`yy1', {c $|}`yy2' and {c $|}`yy4'), at the minimum taxable earnings ({c $|}`fyy0'), at the FPL and 1.3 x FPL ({c $|}`F' and" "{c $|}`F2'). Horizontal ticks: at maximum FS and welfare grants. Net income is earnings net of payroll taxes and federal income taxes and" "inclusive of EITC and transfers (given participation). No assistance corresponds to earnings net of payroll taxes and federal income" "taxes and inclusive of EITC.", size(vsmall)) ///
     graphregion(color(white)) bgcolor(white) ///
     name(`whatwedo'_wn, replace) 
	 
	 
	 
						
						
// without title and notes for slides   
 graph twoway line income_0 e, lcolor(black) ||  ///
              connect income_1 e if (mod(_n,30)==1|_n==1), lcolor(black) lpattern(solid) mcolor(black) msymbol(O) msize(vsmall) ||  ///
              line income_4 e, lcolor(red) lpattern(dash) ||  ///
              connect income_5 e if (mod(_n,100)==1|_n==1), lcolor(red*0.5) lpattern(dash) mcolor(red) msymbol(O) msize(vsmall) || ///
              line income_2 e, lcolor(blue) lpattern("-...") ||  ///
              connect income_3 e if (mod(_n,100)==1|_n==1), lcolor(blue*0.5) lpattern("-...") mcolor(blue) msymbol(O) msize(vsmall) || ///
              line e e, lcolor(black) lpattern(shortdash) ///
     xtitle("Gross Earnings", size(small)) ///
     ytitle("Net Income", size(small)) ///
     ylabel(`b1' `map', nogrid angle(horizonal) labsize(small)) ///
     xlabel(`er' `yy1' `ebreakeven' `yy2' `F' `fyy0' `F2' `yy4', nogrid angle(60) labsize(small)) ///
     xline(`er', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`ebreakeven', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`yy1', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`yy2', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`F', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`fyy0', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`F2', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     xline(`yy4', lcolor(black) lpattern(dot) lwidth(vthin)) ///
     legend( ///
        lab(1 "Off Welfare and FS") ///
        lab(2 "On FS") ///
        lab(3 "On Welfare (JF)") ///
     	lab(4 "On Welfare + FS (JF)") ///
        lab(5 "On Welfare (AFDC)") ///
        lab(6 "On Welfare + FS (AFDC)") ///
        lab(7 "45 degree line") ///
        size(vsmall) ///
        order(7 1 2 3 4 5 6) ///
        region(lwidth(none) lstyle(none) lcolor(white) lpattern(blank) color(none)) ///
        position(4) ring(0) col(1) bmargin(large) ///
     ) ///
     graphregion(color(white)) bgcolor(white) ///
     name(`whatwedo', replace) 
  graph export "${gJF}/`whatwedo'.pdf", logo(off) orientation(landscape) mag(100) replace 




      
      
      

